@@ -386,13 +386,13 @@ static int puzzle_fill_avglgls(PuzzleContext * const context,
     do {
         ly = 0U;
         do {
-            x = xshift + (double) lx * width / SUCC(lambdas);
-            y = yshift + (double) ly * height / SUCC(lambdas);
+            x = xshift + (double) lx * PRED(width) / SUCC(lambdas);
+            y = yshift + (double) ly * PRED(height) / SUCC(lambdas);
             lwidth = (unsigned int) round
-                (xshift + (double) SUCC(lx) * width /
+                (xshift + (double) SUCC(lx) * PRED(width) /
                  (double) SUCC(lambdas) - x);
             lheight = (unsigned int) round
-                (yshift + (double) SUCC(ly) * height /
+                (yshift + (double) SUCC(ly) * PRED(height) /
                  (double) SUCC(lambdas) - y);
             if (p < lwidth) {                
                 xd = (unsigned int) round(x + (lwidth - p) / 2.0);
